LString (imandrax-ocaml.Imandrax_ocaml_prelude.Prelude_extracted.LString)

`type t = LChar.t list`
`val empty : t`
`val of_list : 'a -> 'a`
`val to_string : t -> string`
`val of_string : string -> LChar.t list`
`val length : t -> Imandrax_util.Z.t`
`val pp : Stdlib.Format.formatter -> LChar.t list -> unit`
`val len_pos : t -> bool`
`val len_zero_inversion : t -> bool`
`val append : t -> t -> t`
`val (^^) : t -> t -> t`
`val for_all : (LChar.t -> bool) -> t -> bool`
`val exists : (LChar.t -> bool) -> t -> bool`
`val concat : t -> LChar.t list list -> LChar.t list`
`val is_printable : t -> bool`
`val sub : t -> int -> int -> t`
`val prefix : t -> t -> bool`
`val suffix : t -> t -> bool`
`val contains : t -> t -> bool`

`contains s1 s2` is `true` if `s2` is a substring of `s1`

`val take : int -> t -> t`
`val drop : int -> t -> t`